from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from arlas_api_python.api.collections_api import CollectionsApi
from arlas_api_python.api.explore_api import ExploreApi



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.api.explore_api import ExploreApi  # noqa: E501
from arlas_api_python.rest import ApiException


class TestExploreApi(unittest.TestCase):
    """ExploreApi unit test stubs"""

    def setUp(self):
        self.api = arlas_api_python.api.explore_api.ExploreApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_aggregate(self):
        """Test case for aggregate

        Aggregate  # noqa: E501
        """
        pass

    def test_aggregate_post(self):
        """Test case for aggregate_post

        Aggregate  # noqa: E501
        """
        pass

    def test_compute(self):
        """Test case for compute

        Compute  # noqa: E501
        """
        pass

    def test_compute_post(self):
        """Test case for compute_post

        Compute  # noqa: E501
        """
        pass

    def test_count(self):
        """Test case for count

        Count  # noqa: E501
        """
        pass

    def test_count_post(self):
        """Test case for count_post

        Count  # noqa: E501
        """
        pass

    def test_describe(self):
        """Test case for describe

        Describe  # noqa: E501
        """
        pass

    def test_geoaggregate(self):
        """Test case for geoaggregate

        GeoAggregate  # noqa: E501
        """
        pass

    def test_geoaggregate_post(self):
        """Test case for geoaggregate_post

        GeoAggregate  # noqa: E501
        """
        pass

    def test_geohashgeoaggregate(self):
        """Test case for geohashgeoaggregate

        GeoAggregate on a geohash  # noqa: E501
        """
        pass

    def test_geosearch(self):
        """Test case for geosearch

        GeoSearch  # noqa: E501
        """
        pass

    def test_geosearch_post(self):
        """Test case for geosearch_post

        GeoSearch  # noqa: E501
        """
        pass

    def test_geotilegeoaggregate(self):
        """Test case for geotilegeoaggregate

        GeoAggregate on a geotile  # noqa: E501
        """
        pass

    def test_get_arlas_hit(self):
        """Test case for get_arlas_hit

        Get an Arlas document  # noqa: E501
        """
        pass

    def test_list(self):
        """Test case for list

        List  # noqa: E501
        """
        pass

    def test_search(self):
        """Test case for search

        Search  # noqa: E501
        """
        pass

    def test_search_post(self):
        """Test case for search_post

        Search  # noqa: E501
        """
        pass

    def test_shapeaggregate(self):
        """Test case for shapeaggregate

        ShapeAggregate  # noqa: E501
        """
        pass

    def test_shapeaggregate_post(self):
        """Test case for shapeaggregate_post

        ShapeAggregate  # noqa: E501
        """
        pass

    def test_shapesearch(self):
        """Test case for shapesearch

        ShapeSearch  # noqa: E501
        """
        pass

    def test_shapesearch_post(self):
        """Test case for shapesearch_post

        ShapeSearch  # noqa: E501
        """
        pass

    def test_suggest(self):
        """Test case for suggest

        Suggest  # noqa: E501
        """
        pass

    def test_tiledgeosearch(self):
        """Test case for tiledgeosearch

        Tiled GeoSearch  # noqa: E501
        """
        pass

    def test_tiledgeosearch1(self):
        """Test case for tiledgeosearch1

        Tiled GeoSearch  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DublinCoreElementName(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'str',
        'creator': 'str',
        'subject': 'str',
        'description': 'str',
        'publisher': 'str',
        'contributor': 'str',
        'type': 'str',
        'format': 'str',
        'identifier': 'str',
        'source': 'str',
        'language': 'str',
        'bbox': 'Bbox',
        '_date': 'str',
        'coverage': 'dict(str, object)',
        'coverage_centroid': 'str'
    }

    attribute_map = {
        'title': 'title',
        'creator': 'creator',
        'subject': 'subject',
        'description': 'description',
        'publisher': 'publisher',
        'contributor': 'contributor',
        'type': 'type',
        'format': 'format',
        'identifier': 'identifier',
        'source': 'source',
        'language': 'language',
        'bbox': 'bbox',
        '_date': 'date',
        'coverage': 'coverage',
        'coverage_centroid': 'coverage_centroid'
    }

    def __init__(self, title=None, creator=None, subject=None, description=None, publisher=None, contributor=None, type=None, format=None, identifier=None, source=None, language=None, bbox=None, _date=None, coverage=None, coverage_centroid=None):  # noqa: E501
        """DublinCoreElementName - a model defined in Swagger"""  # noqa: E501

        self._title = None
        self._creator = None
        self._subject = None
        self._description = None
        self._publisher = None
        self._contributor = None
        self._type = None
        self._format = None
        self._identifier = None
        self._source = None
        self._language = None
        self._bbox = None
        self.__date = None
        self._coverage = None
        self._coverage_centroid = None
        self.discriminator = None

        if title is not None:
            self.title = title
        if creator is not None:
            self.creator = creator
        if subject is not None:
            self.subject = subject
        if description is not None:
            self.description = description
        if publisher is not None:
            self.publisher = publisher
        if contributor is not None:
            self.contributor = contributor
        if type is not None:
            self.type = type
        if format is not None:
            self.format = format
        if identifier is not None:
            self.identifier = identifier
        if source is not None:
            self.source = source
        if language is not None:
            self.language = language
        if bbox is not None:
            self.bbox = bbox
        if _date is not None:
            self._date = _date
        if coverage is not None:
            self.coverage = coverage
        if coverage_centroid is not None:
            self.coverage_centroid = coverage_centroid

    @property
    def title(self):
        """Gets the title of this DublinCoreElementName.  # noqa: E501


        :return: The title of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DublinCoreElementName.


        :param title: The title of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def creator(self):
        """Gets the creator of this DublinCoreElementName.  # noqa: E501


        :return: The creator of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this DublinCoreElementName.


        :param creator: The creator of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def subject(self):
        """Gets the subject of this DublinCoreElementName.  # noqa: E501


        :return: The subject of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DublinCoreElementName.


        :param subject: The subject of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def description(self):
        """Gets the description of this DublinCoreElementName.  # noqa: E501


        :return: The description of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DublinCoreElementName.


        :param description: The description of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def publisher(self):
        """Gets the publisher of this DublinCoreElementName.  # noqa: E501


        :return: The publisher of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._publisher

    @publisher.setter
    def publisher(self, publisher):
        """Sets the publisher of this DublinCoreElementName.


        :param publisher: The publisher of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._publisher = publisher

    @property
    def contributor(self):
        """Gets the contributor of this DublinCoreElementName.  # noqa: E501


        :return: The contributor of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._contributor

    @contributor.setter
    def contributor(self, contributor):
        """Sets the contributor of this DublinCoreElementName.


        :param contributor: The contributor of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._contributor = contributor

    @property
    def type(self):
        """Gets the type of this DublinCoreElementName.  # noqa: E501


        :return: The type of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DublinCoreElementName.


        :param type: The type of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def format(self):
        """Gets the format of this DublinCoreElementName.  # noqa: E501


        :return: The format of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this DublinCoreElementName.


        :param format: The format of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def identifier(self):
        """Gets the identifier of this DublinCoreElementName.  # noqa: E501


        :return: The identifier of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this DublinCoreElementName.


        :param identifier: The identifier of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._identifier = identifier

    @property
    def source(self):
        """Gets the source of this DublinCoreElementName.  # noqa: E501


        :return: The source of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DublinCoreElementName.


        :param source: The source of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def language(self):
        """Gets the language of this DublinCoreElementName.  # noqa: E501


        :return: The language of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this DublinCoreElementName.


        :param language: The language of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def bbox(self):
        """Gets the bbox of this DublinCoreElementName.  # noqa: E501


        :return: The bbox of this DublinCoreElementName.  # noqa: E501
        :rtype: Bbox
        """
        return self._bbox

    @bbox.setter
    def bbox(self, bbox):
        """Sets the bbox of this DublinCoreElementName.


        :param bbox: The bbox of this DublinCoreElementName.  # noqa: E501
        :type: Bbox
        """

        self._bbox = bbox

    @property
    def _date(self):
        """Gets the _date of this DublinCoreElementName.  # noqa: E501


        :return: The _date of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this DublinCoreElementName.


        :param _date: The _date of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self.__date = _date

    @property
    def coverage(self):
        """Gets the coverage of this DublinCoreElementName.  # noqa: E501


        :return: The coverage of this DublinCoreElementName.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._coverage

    @coverage.setter
    def coverage(self, coverage):
        """Sets the coverage of this DublinCoreElementName.


        :param coverage: The coverage of this DublinCoreElementName.  # noqa: E501
        :type: dict(str, object)
        """

        self._coverage = coverage

    @property
    def coverage_centroid(self):
        """Gets the coverage_centroid of this DublinCoreElementName.  # noqa: E501


        :return: The coverage_centroid of this DublinCoreElementName.  # noqa: E501
        :rtype: str
        """
        return self._coverage_centroid

    @coverage_centroid.setter
    def coverage_centroid(self, coverage_centroid):
        """Sets the coverage_centroid of this DublinCoreElementName.


        :param coverage_centroid: The coverage_centroid of this DublinCoreElementName.  # noqa: E501
        :type: str
        """

        self._coverage_centroid = coverage_centroid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DublinCoreElementName, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DublinCoreElementName):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Filter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'f': 'list[list[Expression]]',
        'q': 'list[list[str]]',
        'dateformat': 'str',
        'righthand': 'bool'
    }

    attribute_map = {
        'f': 'f',
        'q': 'q',
        'dateformat': 'dateformat',
        'righthand': 'righthand'
    }

    def __init__(self, f=None, q=None, dateformat=None, righthand=None):  # noqa: E501
        """Filter - a model defined in Swagger"""  # noqa: E501

        self._f = None
        self._q = None
        self._dateformat = None
        self._righthand = None
        self.discriminator = None

        if f is not None:
            self.f = f
        if q is not None:
            self.q = q
        if dateformat is not None:
            self.dateformat = dateformat
        if righthand is not None:
            self.righthand = righthand

    @property
    def f(self):
        """Gets the f of this Filter.  # noqa: E501


        :return: The f of this Filter.  # noqa: E501
        :rtype: list[list[Expression]]
        """
        return self._f

    @f.setter
    def f(self, f):
        """Sets the f of this Filter.


        :param f: The f of this Filter.  # noqa: E501
        :type: list[list[Expression]]
        """

        self._f = f

    @property
    def q(self):
        """Gets the q of this Filter.  # noqa: E501


        :return: The q of this Filter.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._q

    @q.setter
    def q(self, q):
        """Sets the q of this Filter.


        :param q: The q of this Filter.  # noqa: E501
        :type: list[list[str]]
        """

        self._q = q

    @property
    def dateformat(self):
        """Gets the dateformat of this Filter.  # noqa: E501


        :return: The dateformat of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._dateformat

    @dateformat.setter
    def dateformat(self, dateformat):
        """Sets the dateformat of this Filter.


        :param dateformat: The dateformat of this Filter.  # noqa: E501
        :type: str
        """

        self._dateformat = dateformat

    @property
    def righthand(self):
        """Gets the righthand of this Filter.  # noqa: E501


        :return: The righthand of this Filter.  # noqa: E501
        :rtype: bool
        """
        return self._righthand

    @righthand.setter
    def righthand(self, righthand):
        """Sets the righthand of this Filter.


        :param righthand: The righthand of this Filter.  # noqa: E501
        :type: bool
        """

        self._righthand = righthand

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Filter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Filter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Feed(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'author': 'Person',
        'contributor': 'Person',
        'icon': 'str',
        'logo': 'str',
        'rights': 'str',
        'subtitle': 'str',
        'generator': 'Generator'
    }

    attribute_map = {
        'author': 'author',
        'contributor': 'contributor',
        'icon': 'icon',
        'logo': 'logo',
        'rights': 'rights',
        'subtitle': 'subtitle',
        'generator': 'generator'
    }

    def __init__(self, author=None, contributor=None, icon=None, logo=None, rights=None, subtitle=None, generator=None):  # noqa: E501
        """Feed - a model defined in Swagger"""  # noqa: E501

        self._author = None
        self._contributor = None
        self._icon = None
        self._logo = None
        self._rights = None
        self._subtitle = None
        self._generator = None
        self.discriminator = None

        if author is not None:
            self.author = author
        if contributor is not None:
            self.contributor = contributor
        if icon is not None:
            self.icon = icon
        if logo is not None:
            self.logo = logo
        if rights is not None:
            self.rights = rights
        if subtitle is not None:
            self.subtitle = subtitle
        if generator is not None:
            self.generator = generator

    @property
    def author(self):
        """Gets the author of this Feed.  # noqa: E501


        :return: The author of this Feed.  # noqa: E501
        :rtype: Person
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this Feed.


        :param author: The author of this Feed.  # noqa: E501
        :type: Person
        """

        self._author = author

    @property
    def contributor(self):
        """Gets the contributor of this Feed.  # noqa: E501


        :return: The contributor of this Feed.  # noqa: E501
        :rtype: Person
        """
        return self._contributor

    @contributor.setter
    def contributor(self, contributor):
        """Sets the contributor of this Feed.


        :param contributor: The contributor of this Feed.  # noqa: E501
        :type: Person
        """

        self._contributor = contributor

    @property
    def icon(self):
        """Gets the icon of this Feed.  # noqa: E501


        :return: The icon of this Feed.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this Feed.


        :param icon: The icon of this Feed.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def logo(self):
        """Gets the logo of this Feed.  # noqa: E501


        :return: The logo of this Feed.  # noqa: E501
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this Feed.


        :param logo: The logo of this Feed.  # noqa: E501
        :type: str
        """

        self._logo = logo

    @property
    def rights(self):
        """Gets the rights of this Feed.  # noqa: E501


        :return: The rights of this Feed.  # noqa: E501
        :rtype: str
        """
        return self._rights

    @rights.setter
    def rights(self, rights):
        """Sets the rights of this Feed.


        :param rights: The rights of this Feed.  # noqa: E501
        :type: str
        """

        self._rights = rights

    @property
    def subtitle(self):
        """Gets the subtitle of this Feed.  # noqa: E501


        :return: The subtitle of this Feed.  # noqa: E501
        :rtype: str
        """
        return self._subtitle

    @subtitle.setter
    def subtitle(self, subtitle):
        """Sets the subtitle of this Feed.


        :param subtitle: The subtitle of this Feed.  # noqa: E501
        :type: str
        """

        self._subtitle = subtitle

    @property
    def generator(self):
        """Gets the generator of this Feed.  # noqa: E501


        :return: The generator of this Feed.  # noqa: E501
        :rtype: Generator
        """
        return self._generator

    @generator.setter
    def generator(self, generator):
        """Sets the generator of this Feed.


        :param generator: The generator of this Feed.  # noqa: E501
        :type: Generator
        """

        self._generator = generator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Feed, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Feed):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MD(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'timestamp': 'int',
        'geometry': 'object',
        'centroid': 'object',
        'returned_geometries': 'list[Geo]'
    }

    attribute_map = {
        'id': 'id',
        'timestamp': 'timestamp',
        'geometry': 'geometry',
        'centroid': 'centroid',
        'returned_geometries': 'returned_geometries'
    }

    def __init__(self, id=None, timestamp=None, geometry=None, centroid=None, returned_geometries=None):  # noqa: E501
        """MD - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._timestamp = None
        self._geometry = None
        self._centroid = None
        self._returned_geometries = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if timestamp is not None:
            self.timestamp = timestamp
        if geometry is not None:
            self.geometry = geometry
        if centroid is not None:
            self.centroid = centroid
        if returned_geometries is not None:
            self.returned_geometries = returned_geometries

    @property
    def id(self):
        """Gets the id of this MD.  # noqa: E501


        :return: The id of this MD.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MD.


        :param id: The id of this MD.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def timestamp(self):
        """Gets the timestamp of this MD.  # noqa: E501


        :return: The timestamp of this MD.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this MD.


        :param timestamp: The timestamp of this MD.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def geometry(self):
        """Gets the geometry of this MD.  # noqa: E501


        :return: The geometry of this MD.  # noqa: E501
        :rtype: object
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this MD.


        :param geometry: The geometry of this MD.  # noqa: E501
        :type: object
        """

        self._geometry = geometry

    @property
    def centroid(self):
        """Gets the centroid of this MD.  # noqa: E501


        :return: The centroid of this MD.  # noqa: E501
        :rtype: object
        """
        return self._centroid

    @centroid.setter
    def centroid(self, centroid):
        """Sets the centroid of this MD.


        :param centroid: The centroid of this MD.  # noqa: E501
        :type: object
        """

        self._centroid = centroid

    @property
    def returned_geometries(self):
        """Gets the returned_geometries of this MD.  # noqa: E501


        :return: The returned_geometries of this MD.  # noqa: E501
        :rtype: list[Geo]
        """
        return self._returned_geometries

    @returned_geometries.setter
    def returned_geometries(self, returned_geometries):
        """Sets the returned_geometries of this MD.


        :param returned_geometries: The returned_geometries of this MD.  # noqa: E501
        :type: list[Geo]
        """

        self._returned_geometries = returned_geometries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MD, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MD):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.models.multi_point import MultiPoint  # noqa: E501
from arlas_api_python.rest import ApiException


class TestMultiPoint(unittest.TestCase):
    """MultiPoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMultiPoint(self):
        """Test MultiPoint"""
        # FIXME: construct object with mandatory attributes with example values
        # model = arlas_api_python.models.multi_point.MultiPoint()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CollectionReferenceDescriptionProperty(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'format': 'str',
        'properties': 'dict(str, CollectionReferenceDescriptionProperty)',
        'taggable': 'bool',
        'indexed': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'format': 'format',
        'properties': 'properties',
        'taggable': 'taggable',
        'indexed': 'indexed'
    }

    def __init__(self, type=None, format=None, properties=None, taggable=None, indexed=None):  # noqa: E501
        """CollectionReferenceDescriptionProperty - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._format = None
        self._properties = None
        self._taggable = None
        self._indexed = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if format is not None:
            self.format = format
        if properties is not None:
            self.properties = properties
        if taggable is not None:
            self.taggable = taggable
        if indexed is not None:
            self.indexed = indexed

    @property
    def type(self):
        """Gets the type of this CollectionReferenceDescriptionProperty.  # noqa: E501


        :return: The type of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CollectionReferenceDescriptionProperty.


        :param type: The type of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :type: str
        """
        allowed_values = ["TEXT", "KEYWORD", "LONG", "INTEGER", "SHORT", "BYTE", "DOUBLE", "FLOAT", "DATE", "BOOLEAN", "BINARY", "INT_RANGE", "FLOAT_RANGE", "LONG_RANGE", "DOUBLE_RANGE", "DATE_RANGE", "OBJECT", "NESTED", "GEO_POINT", "GEO_SHAPE", "IP", "COMPLETION", "TOKEN_COUNT", "MAPPER_MURMUR3", "UNKNOWN", "VARCHAR", "CHAR", "CHARACTER", "BIT", "TINYINT", "SMALLINT", "INT", "BIGINT", "DECIMAL", "NUMERIC", "REAL", "DOUBLEPRECISION", "TIMESTAMP", "TIME", "INTERVAL", "GEOMETRY", "GEOGRAPHY", "POINT", "LINESTRING", "POLYGON", "MULTIPOINT", "MULTILINESTRING", "MULTIPOLYGON", "GEOMETRYCOLLECTION"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def format(self):
        """Gets the format of this CollectionReferenceDescriptionProperty.  # noqa: E501


        :return: The format of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this CollectionReferenceDescriptionProperty.


        :param format: The format of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def properties(self):
        """Gets the properties of this CollectionReferenceDescriptionProperty.  # noqa: E501


        :return: The properties of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :rtype: dict(str, CollectionReferenceDescriptionProperty)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this CollectionReferenceDescriptionProperty.


        :param properties: The properties of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :type: dict(str, CollectionReferenceDescriptionProperty)
        """

        self._properties = properties

    @property
    def taggable(self):
        """Gets the taggable of this CollectionReferenceDescriptionProperty.  # noqa: E501


        :return: The taggable of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :rtype: bool
        """
        return self._taggable

    @taggable.setter
    def taggable(self, taggable):
        """Sets the taggable of this CollectionReferenceDescriptionProperty.


        :param taggable: The taggable of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :type: bool
        """

        self._taggable = taggable

    @property
    def indexed(self):
        """Gets the indexed of this CollectionReferenceDescriptionProperty.  # noqa: E501


        :return: The indexed of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :rtype: bool
        """
        return self._indexed

    @indexed.setter
    def indexed(self, indexed):
        """Sets the indexed of this CollectionReferenceDescriptionProperty.


        :param indexed: The indexed of this CollectionReferenceDescriptionProperty.  # noqa: E501
        :type: bool
        """

        self._indexed = indexed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CollectionReferenceDescriptionProperty, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionReferenceDescriptionProperty):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Inspire(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'keywords': 'list[Keyword]',
        'topic_categories': 'list[str]',
        'lineage': 'str',
        'languages': 'list[str]',
        'spatial_resolution': 'InspireSpatialResolution',
        'inspire_uri': 'InspireURI',
        'inspire_limitation_access': 'InspireLimitationAccess',
        'inspire_use_conditions': 'str'
    }

    attribute_map = {
        'keywords': 'keywords',
        'topic_categories': 'topic_categories',
        'lineage': 'lineage',
        'languages': 'languages',
        'spatial_resolution': 'spatial_resolution',
        'inspire_uri': 'inspire_uri',
        'inspire_limitation_access': 'inspire_limitation_access',
        'inspire_use_conditions': 'inspire_use_conditions'
    }

    def __init__(self, keywords=None, topic_categories=None, lineage=None, languages=None, spatial_resolution=None, inspire_uri=None, inspire_limitation_access=None, inspire_use_conditions=None):  # noqa: E501
        """Inspire - a model defined in Swagger"""  # noqa: E501

        self._keywords = None
        self._topic_categories = None
        self._lineage = None
        self._languages = None
        self._spatial_resolution = None
        self._inspire_uri = None
        self._inspire_limitation_access = None
        self._inspire_use_conditions = None
        self.discriminator = None

        if keywords is not None:
            self.keywords = keywords
        if topic_categories is not None:
            self.topic_categories = topic_categories
        if lineage is not None:
            self.lineage = lineage
        if languages is not None:
            self.languages = languages
        if spatial_resolution is not None:
            self.spatial_resolution = spatial_resolution
        if inspire_uri is not None:
            self.inspire_uri = inspire_uri
        if inspire_limitation_access is not None:
            self.inspire_limitation_access = inspire_limitation_access
        if inspire_use_conditions is not None:
            self.inspire_use_conditions = inspire_use_conditions

    @property
    def keywords(self):
        """Gets the keywords of this Inspire.  # noqa: E501


        :return: The keywords of this Inspire.  # noqa: E501
        :rtype: list[Keyword]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this Inspire.


        :param keywords: The keywords of this Inspire.  # noqa: E501
        :type: list[Keyword]
        """

        self._keywords = keywords

    @property
    def topic_categories(self):
        """Gets the topic_categories of this Inspire.  # noqa: E501


        :return: The topic_categories of this Inspire.  # noqa: E501
        :rtype: list[str]
        """
        return self._topic_categories

    @topic_categories.setter
    def topic_categories(self, topic_categories):
        """Sets the topic_categories of this Inspire.


        :param topic_categories: The topic_categories of this Inspire.  # noqa: E501
        :type: list[str]
        """

        self._topic_categories = topic_categories

    @property
    def lineage(self):
        """Gets the lineage of this Inspire.  # noqa: E501


        :return: The lineage of this Inspire.  # noqa: E501
        :rtype: str
        """
        return self._lineage

    @lineage.setter
    def lineage(self, lineage):
        """Sets the lineage of this Inspire.


        :param lineage: The lineage of this Inspire.  # noqa: E501
        :type: str
        """

        self._lineage = lineage

    @property
    def languages(self):
        """Gets the languages of this Inspire.  # noqa: E501


        :return: The languages of this Inspire.  # noqa: E501
        :rtype: list[str]
        """
        return self._languages

    @languages.setter
    def languages(self, languages):
        """Sets the languages of this Inspire.


        :param languages: The languages of this Inspire.  # noqa: E501
        :type: list[str]
        """

        self._languages = languages

    @property
    def spatial_resolution(self):
        """Gets the spatial_resolution of this Inspire.  # noqa: E501


        :return: The spatial_resolution of this Inspire.  # noqa: E501
        :rtype: InspireSpatialResolution
        """
        return self._spatial_resolution

    @spatial_resolution.setter
    def spatial_resolution(self, spatial_resolution):
        """Sets the spatial_resolution of this Inspire.


        :param spatial_resolution: The spatial_resolution of this Inspire.  # noqa: E501
        :type: InspireSpatialResolution
        """

        self._spatial_resolution = spatial_resolution

    @property
    def inspire_uri(self):
        """Gets the inspire_uri of this Inspire.  # noqa: E501


        :return: The inspire_uri of this Inspire.  # noqa: E501
        :rtype: InspireURI
        """
        return self._inspire_uri

    @inspire_uri.setter
    def inspire_uri(self, inspire_uri):
        """Sets the inspire_uri of this Inspire.


        :param inspire_uri: The inspire_uri of this Inspire.  # noqa: E501
        :type: InspireURI
        """

        self._inspire_uri = inspire_uri

    @property
    def inspire_limitation_access(self):
        """Gets the inspire_limitation_access of this Inspire.  # noqa: E501


        :return: The inspire_limitation_access of this Inspire.  # noqa: E501
        :rtype: InspireLimitationAccess
        """
        return self._inspire_limitation_access

    @inspire_limitation_access.setter
    def inspire_limitation_access(self, inspire_limitation_access):
        """Sets the inspire_limitation_access of this Inspire.


        :param inspire_limitation_access: The inspire_limitation_access of this Inspire.  # noqa: E501
        :type: InspireLimitationAccess
        """

        self._inspire_limitation_access = inspire_limitation_access

    @property
    def inspire_use_conditions(self):
        """Gets the inspire_use_conditions of this Inspire.  # noqa: E501


        :return: The inspire_use_conditions of this Inspire.  # noqa: E501
        :rtype: str
        """
        return self._inspire_use_conditions

    @inspire_use_conditions.setter
    def inspire_use_conditions(self, inspire_use_conditions):
        """Sets the inspire_use_conditions of this Inspire.


        :param inspire_use_conditions: The inspire_use_conditions of this Inspire.  # noqa: E501
        :type: str
        """

        self._inspire_use_conditions = inspire_use_conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Inspire, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Inspire):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FeatureCollection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'crs': 'Crs',
        'bbox': 'list[float]',
        'features': 'list[Feature]'
    }

    attribute_map = {
        'crs': 'crs',
        'bbox': 'bbox',
        'features': 'features'
    }

    def __init__(self, crs=None, bbox=None, features=None):  # noqa: E501
        """FeatureCollection - a model defined in Swagger"""  # noqa: E501

        self._crs = None
        self._bbox = None
        self._features = None
        self.discriminator = None

        if crs is not None:
            self.crs = crs
        if bbox is not None:
            self.bbox = bbox
        if features is not None:
            self.features = features

    @property
    def crs(self):
        """Gets the crs of this FeatureCollection.  # noqa: E501


        :return: The crs of this FeatureCollection.  # noqa: E501
        :rtype: Crs
        """
        return self._crs

    @crs.setter
    def crs(self, crs):
        """Sets the crs of this FeatureCollection.


        :param crs: The crs of this FeatureCollection.  # noqa: E501
        :type: Crs
        """

        self._crs = crs

    @property
    def bbox(self):
        """Gets the bbox of this FeatureCollection.  # noqa: E501


        :return: The bbox of this FeatureCollection.  # noqa: E501
        :rtype: list[float]
        """
        return self._bbox

    @bbox.setter
    def bbox(self, bbox):
        """Sets the bbox of this FeatureCollection.


        :param bbox: The bbox of this FeatureCollection.  # noqa: E501
        :type: list[float]
        """

        self._bbox = bbox

    @property
    def features(self):
        """Gets the features of this FeatureCollection.  # noqa: E501


        :return: The features of this FeatureCollection.  # noqa: E501
        :rtype: list[Feature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this FeatureCollection.


        :param features: The features of this FeatureCollection.  # noqa: E501
        :type: list[Feature]
        """

        self._features = features

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeatureCollection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeatureCollection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
